@@ -14,10 +14,9 @@
 #  limitations under the License.
 
 import copy
-from utils.XY import XY
 from elements import DiagramNode
 import noderenderer
-from utils import Box
+from utils import Box, Size, XY
 from utils.collections import defaultdict, namedtuple
 
 cellsize = 8
@@ -92,6 +91,8 @@ class AutoScaler(object):
         klass = value.__class__
         if klass == XY:
             ret = XY(value.x * ratio, value.y * ratio)
+        elif klass == Size:
+            ret = Size(value.width * ratio, value.height * ratio)
         elif klass == Box:
             ret = Box(value[0] * ratio, value[1] * ratio,
                       value[2] * ratio, value[3] * ratio)
@@ -104,12 +105,15 @@ class AutoScaler(object):
             ret.polylines = cls.scale(value.polylines, ratio)
         elif klass == int:
             ret = value * ratio
+        elif klass == str:
+            ret = value
         else:
             ret = cls(value, ratio)
 
         return ret
 
-    def originalMetrics(self):
+    @property
+    def original_metrics(self):
         return self.subject
 
 
@@ -121,6 +125,7 @@ class DiagramMetrics(object):
     shadow_offset = XY(3, 6)
     font = 11
     fontsize = 11
+    page_margin = XY(0, 0)
     page_padding = [0, 0, 0, 0]
     node_width = cellsize * 16
     node_height = cellsize * 5
@@ -128,6 +133,8 @@ class DiagramMetrics(object):
     span_height = cellsize * 5
 
     def __init__(self, diagram, **kwargs):
+        self.format = kwargs.get('format')
+
         if diagram.node_width is not None:
             self.node_width = diagram.node_width
 
@@ -153,16 +160,6 @@ class DiagramMetrics(object):
         if diagram.edge_layout is not None:
             self.edge_layout = diagram.edge_layout
 
-        page_margin_x = cellsize * 3
-        if page_margin_x < self.span_width:
-            page_margin_x = self.span_width
-
-        page_margin_y = cellsize * 3
-        if page_margin_y < self.span_height:
-            page_margin_y = self.span_height + cellsize
-
-        self.page_margin = XY(page_margin_x, page_margin_y)
-
         # setup spreadsheet
         sheet = self.spreadsheet = SpreadSheetMetrics(self)
         nodes = [n for n in diagram.traverse_nodes() if n.drawable]
@@ -181,20 +178,33 @@ class DiagramMetrics(object):
                 height = max(n or node_height for n in heights)
                 sheet.set_node_height(y, height)
 
-    def originalMetrics(self):
+    @property
+    def original_metrics(self):
         return self
 
-    def shiftedMetrics(self, top, right, bottom, left):
+    def shift(self, x, y):
         metrics = copy.copy(self)
         metrics.spreadsheet = copy.copy(self.spreadsheet)
         metrics.spreadsheet.metrics = metrics
-
-        padding = metrics.page_padding
-        metrics.page_padding = [padding[0] + top, padding[1] + right,
-                               padding[2] + bottom, padding[3] + left]
+        metrics.page_margin = XY(x, y)
 
         return metrics
 
+    def textsize(self, string, width=65535, fontsize=None):
+        try:
+            if self.format == 'PDF':
+                from utils.PDFTextFolder import PILTextFolder as TextFolder
+            else:
+                from utils.PILTextFolder import PILTextFolder as TextFolder
+        except ImportError:
+            from utils.TextFolder import TextFolder
+
+        fontsize = fontsize or self.fontsize
+        lines = TextFolder((0, 0, width, 65535), string,
+                           font=self.font, fontsize=fontsize)
+        textbox = lines.outlinebox
+        return XY(textbox.width, textbox.height + self.line_spacing)
+
     def node(self, node):
         renderer = noderenderer.get(node.shape)
 
@@ -268,8 +278,8 @@ class SpreadSheetMetrics(object):
 
         node_width = sum(self.node_width[i] for i in range(x))
         node_height = sum(self.node_height[i] for i in range(y))
-        span_width = sum(self.span_width[i] for i in range(x))
-        span_height = sum(self.span_height[i] for i in range(y))
+        span_width = sum(self.span_width[i] for i in range(x + 1))
+        span_height = sum(self.span_height[i] for i in range(y + 1))
 
         if use_padding:
             xdiff = (self.node_width[x] - (node.width or m.node_width)) / 2
@@ -292,8 +302,8 @@ class SpreadSheetMetrics(object):
 
         node_width = sum(self.node_width[i] for i in range(x + 1))
         node_height = sum(self.node_height[i] for i in range(y + 1))
-        span_width = sum(self.span_width[i] for i in range(x))
-        span_height = sum(self.span_height[i] for i in range(y))
+        span_width = sum(self.span_width[i] for i in range(x + 1))
+        span_height = sum(self.span_height[i] for i in range(y + 1))
 
         if use_padding:
             xdiff = (self.node_width[x] - (node.width or m.node_width)) / 2
@@ -314,7 +324,10 @@ class SpreadSheetMetrics(object):
         dummy = DiagramNode(None)
         dummy.xy = XY(width - 1, height - 1)
         x, y = self._node_bottomright(dummy, use_padding=False)
-        return XY(x + margin.x + padding[1], y + margin.y + padding[2])
+        x_span = self.span_width[width + 1]
+        y_span = self.span_height[height + 1]
+        return XY(x + margin.x + padding[1] + x_span,
+                  y + margin.y + padding[2] + y_span)
 
 
 class NodeMetrics(Box):
@@ -345,50 +358,24 @@ class NodeMetrics(Box):
         return Box(self.x1, self.y1 - self.metrics.span_height / 2,
                    self.x2, self.y1)
 
-    @property
-    def topleft(self):
-        return XY(self.x1, self.y1)
-
-    @property
-    def top(self):
-        return XY(self.x1 + self.width / 2, self.y1)
-
-    @property
-    def topright(self):
-        return XY(self.x2, self.y1)
-
-    @property
-    def bottomleft(self):
-        return XY(self.x1, self.y2)
-
-    @property
-    def bottom(self):
-        return XY(self.x1 + self.width / 2, self.y2)
-
-    @property
-    def bottomright(self):
-        return XY(self.x2, self.y2)
-
-    @property
-    def left(self):
-        return XY(self.x1, self.y1 + self.height / 2)
-
-    @property
-    def right(self):
-        return XY(self.x2, self.y1 + self.height / 2)
-
-    @property
-    def center(self):
-        return XY(self.x1 + self.width / 2, self.y1 + self.height / 2)
-
 
 class EdgeMetrics(object):
     def __init__(self, edge, metrics):
         self.metrics = metrics
         self.edge = edge
 
+    @property
     def heads(self):
-        pass
+        heads = []
+        head1, head2 = self.headshapes
+
+        if head1:
+            heads.append(self._head(self.edge.node1, head1))
+
+        if head2:
+            heads.append(self._head(self.edge.node2, head2))
+
+        return heads
 
     def _head(self, node, direct):
         head = []
@@ -397,76 +384,110 @@ class EdgeMetrics(object):
 
         if direct == 'up':
             xy = node.bottom
-            head.append(xy)
+            head.append(XY(xy.x, xy.y + 1))
             head.append(XY(xy.x - cell / 2, xy.y + cell))
             head.append(XY(xy.x, xy.y + cell * 2))
             head.append(XY(xy.x + cell / 2, xy.y + cell))
-            head.append(xy)
+            head.append(XY(xy.x, xy.y + 1))
         elif direct == 'down':
             xy = node.top
-            head.append(xy)
+            head.append(XY(xy.x, xy.y - 1))
             head.append(XY(xy.x - cell / 2, xy.y - cell))
             head.append(XY(xy.x, xy.y - cell * 2))
             head.append(XY(xy.x + cell / 2, xy.y - cell))
-            head.append(xy)
+            head.append(XY(xy.x, xy.y - 1))
         elif direct == 'right':
             xy = node.left
-            head.append(xy)
+            head.append(XY(xy.x - 1, xy.y))
             head.append(XY(xy.x - cell, xy.y - cell / 2))
             head.append(XY(xy.x - cell * 2, xy.y))
             head.append(XY(xy.x - cell, xy.y + cell / 2))
-            head.append(xy)
+            head.append(XY(xy.x - 1, xy.y))
         elif direct == 'left':
             xy = node.right
-            head.append(xy)
+            head.append(XY(xy.x + 1, xy.y))
             head.append(XY(xy.x + cell, xy.y - cell / 2))
             head.append(XY(xy.x + cell * 2, xy.y))
             head.append(XY(xy.x + cell, xy.y + cell / 2))
-            head.append(xy)
+            head.append(XY(xy.x + 1, xy.y))
 
         if self.edge.hstyle not in ('composition', 'aggregation'):
             head.pop(2)
 
         return head
 
+    @property
     def shaft(self):
-        pass
+        cell = self.metrics.cellsize
+        lines = self._shaft
+        head1, head2 = self.headshapes
 
+        if head1:
+            pt = lines.polylines[0].pop(0)
+            if head1 == 'up':
+                lines.polylines[0].insert(0, XY(pt.x, pt.y + cell))
+            elif head1 == 'right':
+                lines.polylines[0].insert(0, XY(pt.x - cell, pt.y))
+            elif head1 == 'left':
+                lines.polylines[0].insert(0, XY(pt.x + cell, pt.y))
+            elif head1 == 'down':
+                lines.polylines[0].insert(0, XY(pt.x, pt.y - cell))
+
+        if head2:
+            pt = lines.polylines[-1].pop()
+            if head2 == 'up':
+                lines.polylines[-1].append(XY(pt.x, pt.y + cell))
+            elif head2 == 'right':
+                lines.polylines[-1].append(XY(pt.x - cell, pt.y))
+            elif head2 == 'left':
+                lines.polylines[-1].append(XY(pt.x + cell, pt.y))
+            elif head2 == 'down':
+                lines.polylines[-1].append(XY(pt.x, pt.y - cell))
+
+        return lines
+
+    @property
     def labelbox(self):
         pass
 
 
 class LandscapeEdgeMetrics(EdgeMetrics):
-    def heads(self):
+    @property
+    def headshapes(self):
         heads = []
         dir = self.edge.direction
 
         if self.edge.dir in ('back', 'both'):
             if dir in ('left-up', 'left', 'same',
                        'right-up', 'right', 'right-down'):
-                heads.append(self._head(self.edge.node1, 'left'))
+                heads.append('left')
             elif dir == 'up':
                 if self.edge.skipped:
-                    heads.append(self._head(self.edge.node1, 'left'))
+                    heads.append('left')
                 else:
-                    heads.append(self._head(self.edge.node1, 'down'))
+                    heads.append('down')
             elif dir in ('left-down', 'down'):
                 if self.edge.skipped:
-                    heads.append(self._head(self.edge.node1, 'left'))
+                    heads.append('left')
                 else:
-                    heads.append(self._head(self.edge.node1, 'up'))
+                    heads.append('up')
+        else:
+            heads.append(None)
 
         if self.edge.dir in ('forward', 'both'):
             if dir in ('right-up', 'right', 'right-down'):
-                heads.append(self._head(self.edge.node2, 'right'))
+                heads.append('right')
             elif dir == 'up':
-                heads.append(self._head(self.edge.node2, 'up'))
+                heads.append('up')
             elif dir in ('left-up', 'left', 'left-down', 'down', 'same'):
-                heads.append(self._head(self.edge.node2, 'down'))
+                heads.append('down')
+        else:
+            heads.append(None)
 
         return heads
 
-    def shaft(self):
+    @property
+    def _shaft(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
         dir = self.edge.direction
 
@@ -571,6 +592,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
         return shaft
 
+    @property
     def labelbox(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
         node = XY(self.metrics.node_width, self.metrics.node_height)
@@ -581,82 +603,88 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
         if dir == 'right':
             if self.edge.skipped:
-                box = (node1.bottomright.x + span.x,
-                       node1.bottomright.y,
-                       node2.bottomleft.x - span.x,
-                       node2.bottomleft.y + span.y / 2)
+                box = Box(node1.bottomright.x + span.x,
+                          node1.bottomright.y,
+                          node2.bottomleft.x - span.x,
+                          node2.bottomleft.y + span.y / 2)
             else:
-                box = (node1.topright.x, node1.topright.y - span.y / 8,
-                       node2.left.x, node2.left.y - span.y / 8)
+                box = Box(node1.topright.x, node1.topright.y - span.y / 8,
+                          node2.left.x, node2.left.y - span.y / 8)
 
         elif dir == 'right-up':
-            box = (node2.left.x - span.x, node1.top.y - node.y / 2,
-                   node2.bottomleft.x, node1.top.y)
+            box = Box(node2.left.x - span.x, node1.top.y - node.y / 2,
+                      node2.bottomleft.x, node1.top.y)
 
         elif dir == 'right-down':
-            box = (node1.right.x, node2.topleft.y - span.y / 8,
-                   node1.right.x + span.x, node2.left.y - span.y / 8)
+            box = Box(node1.right.x, node2.topleft.y - span.y / 8,
+                      node1.right.x + span.x, node2.left.y - span.y / 8)
 
         elif dir in ('up', 'left-up', 'left', 'same'):
             if self.edge.node2.xy.y < self.edge.node1.xy.y:
-                box = (node1.topright.x - span.x / 2 + span.x / 4,
-                       node1.topright.y - span.y / 2,
-                       node1.topright.x + span.x / 2 + span.x / 4,
-                       node1.topright.y)
+                box = Box(node1.topright.x - span.x / 2 + span.x / 4,
+                          node1.topright.y - span.y / 2,
+                          node1.topright.x + span.x / 2 + span.x / 4,
+                          node1.topright.y)
             else:
-                box = (node1.top.x + span.x / 4,
-                       node1.top.y - span.y,
-                       node1.topright.x + span.x / 4,
-                       node1.topright.y - span.y / 2)
+                box = Box(node1.top.x + span.x / 4,
+                          node1.top.y - span.y,
+                          node1.topright.x + span.x / 4,
+                          node1.topright.y - span.y / 2)
 
         elif dir in ('left-down', 'down'):
-            box = (node2.top.x + span.x / 4,
-                   node2.top.y - span.y,
-                   node2.topright.x + span.x / 4,
-                   node2.topright.y - span.y / 2)
+            box = Box(node2.top.x + span.x / 4,
+                      node2.top.y - span.y,
+                      node2.topright.x + span.x / 4,
+                      node2.topright.y - span.y / 2)
 
         # shrink box
-        box = (box[0] + span.x / 8, box[1],
-               box[2] - span.x / 8, box[3])
+        box = Box(box[0] + span.x / 8, box[1],
+                  box[2] - span.x / 8, box[3])
 
         return box
 
 
 class PortraitEdgeMetrics(EdgeMetrics):
-    def heads(self):
+    @property
+    def headshapes(self):
         heads = []
         dir = self.edge.direction
 
         if self.edge.dir in ('back', 'both'):
             if dir == 'right':
                 if self.edge.skipped:
-                    heads.append(self._head(self.edge.node1, 'up'))
+                    heads.append('up')
                 else:
-                    heads.append(self._head(self.edge.node1, 'left'))
+                    heads.append('left')
             elif dir in ('up', 'right-up', 'same'):
-                heads.append(self._head(self.edge.node1, 'up'))
+                heads.append('up')
             elif dir in ('left-up', 'left'):
-                heads.append(self._head(self.edge.node1, 'left'))
+                heads.append('left')
             elif dir in ('left-down', 'down', 'right-down'):
                 if self.edge.skipped:
-                    heads.append(self._head(self.edge.node1, 'left'))
+                    heads.append('left')
                 else:
-                    heads.append(self._head(self.edge.node1, 'up'))
+                    heads.append('up')
+        else:
+            heads.append(None)
 
         if self.edge.dir in ('forward', 'both'):
             if dir == 'right':
                 if self.edge.skipped:
-                    heads.append(self._head(self.edge.node2, 'down'))
+                    heads.append('down')
                 else:
-                    heads.append(self._head(self.edge.node2, 'right'))
+                    heads.append('right')
             elif dir in ('up', 'right-up', 'same'):
-                heads.append(self._head(self.edge.node2, 'down'))
+                heads.append('down')
             elif dir in ('left-up', 'left', 'left-down', 'down', 'right-down'):
-                heads.append(self._head(self.edge.node2, 'down'))
+                heads.append('down')
+        else:
+            heads.append(None)
 
         return heads
 
-    def shaft(self):
+    @property
+    def _shaft(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
         dir = self.edge.direction
 
@@ -735,6 +763,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
 
         return shaft
 
+    @property
     def labelbox(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
 
@@ -744,67 +773,73 @@ class PortraitEdgeMetrics(EdgeMetrics):
 
         if dir == 'right':
             if self.edge.skipped:
-                box = (node1.bottomright.x + span.x,
-                       node1.bottomright.y,
-                       node2.bottomleft.x - span.x,
-                       node2.bottomleft.y + span.y / 2)
+                box = Box(node1.bottomright.x + span.x,
+                          node1.bottomright.y,
+                          node2.bottomleft.x - span.x,
+                          node2.bottomleft.y + span.y / 2)
             else:
-                box = (node1.topright.x, node1.topright.y - span.y / 8,
-                       node2.left.x, node2.left.y - span.y / 8)
+                box = Box(node1.topright.x, node1.topright.y - span.y / 8,
+                          node2.left.x, node2.left.y - span.y / 8)
 
         elif dir == 'right-up':
-            box = (node2.left.x - span.x, node2.left.y,
-                   node2.bottomleft.x, node2.bottomleft.y)
+            box = Box(node2.left.x - span.x, node2.left.y,
+                      node2.bottomleft.x, node2.bottomleft.y)
 
         elif dir == 'right-down':
-            box = (node2.topleft.x, node2.topleft.y - span.y / 2,
-                   node2.top.x, node2.top.y)
+            box = Box(node2.topleft.x, node2.topleft.y - span.y / 2,
+                      node2.top.x, node2.top.y)
 
         elif dir in ('up', 'left-up', 'left', 'same'):
             if self.edge.node2.xy.y < self.edge.node1.xy.y:
-                box = (node1.topright.x - span.x / 2 + span.x / 4,
-                       node1.topright.y - span.y / 2,
-                       node1.topright.x + span.x / 2 + span.x / 4,
-                       node1.topright.y)
+                box = Box(node1.topright.x - span.x / 2 + span.x / 4,
+                          node1.topright.y - span.y / 2,
+                          node1.topright.x + span.x / 2 + span.x / 4,
+                          node1.topright.y)
             else:
-                box = (node1.top.x + span.x / 4,
-                       node1.top.y - span.y,
-                       node1.topright.x + span.x / 4,
-                       node1.topright.y - span.y / 2)
+                box = Box(node1.top.x + span.x / 4,
+                          node1.top.y - span.y,
+                          node1.topright.x + span.x / 4,
+                          node1.topright.y - span.y / 2)
 
         elif dir == 'down':
-            box = (node2.top.x + span.x / 4,
-                   node2.top.y - span.y / 2,
-                   node2.topright.x + span.x / 4,
-                   node2.topright.y)
+            box = Box(node2.top.x + span.x / 4,
+                      node2.top.y - span.y / 2,
+                      node2.topright.x + span.x / 4,
+                      node2.topright.y)
 
         elif dir == 'left-down':
-            box = (node1.bottomleft.x, node1.bottomleft.y,
-                   node1.bottom.x, node1.bottom.y + span.y / 2)
+            box = Box(node1.bottomleft.x, node1.bottomleft.y,
+                      node1.bottom.x, node1.bottom.y + span.y / 2)
 
         # shrink box
-        box = (box[0] + span.x / 8, box[1],
-               box[2] - span.x / 8, box[3])
+        box = Box(box[0] + span.x / 8, box[1],
+                  box[2] - span.x / 8, box[3])
 
         return box
 
 
 class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
-    def heads(self):
+    @property
+    def headshapes(self):
         heads = []
 
         if self.edge.direction == 'right-down':
             if self.edge.dir in ('back', 'both'):
-                heads.append(self._head(self.edge.node1, 'up'))
+                heads.append('up')
+            else:
+                heads.append(None)
 
             if self.edge.dir in ('forward', 'both'):
-                heads.append(self._head(self.edge.node2, 'right'))
+                heads.append('right')
+            else:
+                heads.append(None)
         else:
-            heads = super(FlowchartLandscapeEdgeMetrics, self).heads()
+            heads = super(FlowchartLandscapeEdgeMetrics, self).headshapes
 
         return heads
 
-    def shaft(self):
+    @property
+    def _shaft(self):
         if self.edge.direction == 'right-down':
             span = XY(self.metrics.span_width, self.metrics.span_height)
             node1 = self.metrics.node(self.edge.node1)
@@ -825,10 +860,11 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
 
             shaft.lineTo(node2.left)
         else:
-            shaft = super(FlowchartLandscapeEdgeMetrics, self).shaft()
+            shaft = super(FlowchartLandscapeEdgeMetrics, self)._shaft
 
         return shaft
 
+    @property
     def labelbox(self):
         dir = self.edge.direction
         if dir == 'right':
@@ -839,11 +875,12 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
             cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
             if self.edge.skipped:
-                box = (cell1.bottom.x, cell1.bottom.y,
-                       cell1.bottomright.x, cell1.bottomright.y + span.y / 2)
+                box = Box(cell1.bottom.x, cell1.bottom.y,
+                          cell1.bottomright.x,
+                          cell1.bottomright.y + span.y / 2)
             else:
-                box = (cell1.bottom.x, cell2.left.y - span.y / 2,
-                       cell1.bottom.x, cell2.left.y)
+                box = Box(cell1.bottom.x, cell2.left.y - span.y / 2,
+                          cell1.bottom.x, cell2.left.y)
         else:
             box = super(FlowchartLandscapeEdgeMetrics, self).labelbox()
 
@@ -851,21 +888,27 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
 
 
 class FlowchartPortraitEdgeMetrics(PortraitEdgeMetrics):
-    def heads(self):
+    @property
+    def headshapes(self):
         heads = []
 
         if self.edge.direction == 'right-down':
             if self.edge.dir in ('back', 'both'):
-                heads.append(self._head(self.edge.node1, 'left'))
+                heads.append('left')
+            else:
+                heads.append(None)
 
             if self.edge.dir in ('forward', 'both'):
-                heads.append(self._head(self.edge.node2, 'down'))
+                heads.append('down')
+            else:
+                heads.append(None)
         else:
-            heads = super(FlowchartPortraitEdgeMetrics, self).heads()
+            heads = super(FlowchartPortraitEdgeMetrics, self).headshapes
 
         return heads
 
-    def shaft(self):
+    @property
+    def _shaft(self):
         if self.edge.direction == 'right-down':
             span = XY(self.metrics.span_width, self.metrics.span_height)
             node1 = self.metrics.node(self.edge.node1)
@@ -886,25 +929,30 @@ class FlowchartPortraitEdgeMetrics(PortraitEdgeMetrics):
 
             shaft.lineTo(node2.top)
         else:
-            shaft = super(FlowchartPortraitEdgeMetrics, self).shaft()
+            shaft = super(FlowchartPortraitEdgeMetrics, self)._shaft
 
         return shaft
 
+    @property
     def labelbox(self):
         dir = self.edge.direction
-        if dir == 'right':
-            span = XY(self.metrics.span_width, self.metrics.span_height)
-            node1 = self.metrics.node(self.edge.node1)
-            cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
-            node2 = self.metrics.node(self.edge.node2)
-            cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
+        span = XY(self.metrics.span_width, self.metrics.span_height)
+        node1 = self.metrics.node(self.edge.node1)
+        cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
+        node2 = self.metrics.node(self.edge.node2)
+        cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
+        if dir == 'down':
+            box = Box(cell2.topleft.x, cell2.top.y - span.y / 2,
+                      cell2.top.x, cell2.top.y)
+        elif dir == 'right':
             if self.edge.skipped:
-                box = (cell1.bottom.x, cell1.bottom.y,
-                       cell1.bottomright.x, cell1.bottomright.y + span.y / 2)
+                box = Box(cell1.bottom.x, cell1.bottom.y,
+                          cell1.bottomright.x,
+                          cell1.bottomright.y + span.y / 2)
             else:
-                box = (cell1.bottom.x, cell2.left.y - span.y / 2,
-                       cell1.bottom.x, cell2.left.y)
+                box = Box(cell1.bottom.x, cell2.left.y - span.y / 2,
+                          cell1.bottom.x, cell2.left.y)
         else:
             box = super(FlowchartPortraitEdgeMetrics, self).labelbox()
 
