@@ -20,8 +20,7 @@ from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.cidfonts import UnicodeCIDFont
 from reportlab.pdfbase.ttfonts import TTFont
 from reportlab.lib.units import inch
-from blockdiag.utils.XY import XY
-from blockdiag.utils import urlutil
+from blockdiag.utils import urlutil, XY
 from blockdiag.utils.PDFTextFolder import PDFTextFolder as TextFolder
 
 
@@ -35,6 +34,10 @@ class PDFImageDraw(object):
             msg = "Could not detect fonts, use --font opiton\n"
             raise RuntimeError(msg)
 
+    def set_default_font(self, fontpath, fontsize):
+        self.fontpath = fontpath
+        self.fontsize = fontsize
+
     def set_font(self, fontpath, fontsize):
         if fontpath not in self.fonts:
             ttfont = TTFont(fontpath, fontpath)
@@ -105,32 +108,47 @@ class PDFImageDraw(object):
         self.canvas.rect(x, y, width, height, **params)
 
     def text(self, xy, string, **kwargs):
+        fontsize = kwargs.get('fontsize') or self.fontsize
+
+        self.set_font(self.fontpath, fontsize)
         self.set_fill_color(kwargs.get('fill'))
-        self.set_font(kwargs.get('font'), kwargs.get('fontsize', 11))
         self.canvas.drawString(xy[0], self.size[1] - xy[1], string)
 
     def textarea(self, box, string, **kwargs):
-        self.set_font(kwargs.get('font'), kwargs.get('fontsize', 11))
+        if 'fontsize' in kwargs:
+            fontsize = kwargs.get('fontsize') or self.fontsize
+            del kwargs['fontsize']
+        else:
+            fontsize = self.fontsize
+
+        self.set_font(self.fontpath, fontsize)
         lines = TextFolder(box, string, adjustBaseline=True,
-                           canvas=self.canvas, **kwargs)
+                           canvas=self.canvas, font=self.fontpath,
+                           fontsize=fontsize, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
-            self.rectangle(lines.outlineBox(), fill='white', outline=outline)
+            self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
-        for string, xy in lines.each_line():
-            self.text(xy, string, **kwargs)
+        for string, xy in lines.lines:
+            self.text(xy, string, fontsize=fontsize, **kwargs)
 
     def line(self, xy, **kwargs):
         self.set_stroke_color(kwargs.get('fill', 'none'))
         self.set_style(kwargs.get('style'))
 
+        if 'thick' in kwargs and kwargs['thick'] is not None:
+            self.canvas.setLineWidth(kwargs['thick'])
+
         p1 = xy[0]
         y = self.size[1]
         for p2 in xy[1:]:
             self.canvas.line(p1.x, y - p1.y, p2.x, y - p2.y)
             p1 = p2
 
+        if 'thick' in kwargs:
+            self.canvas.setLineWidth(1)
+
     def arc(self, xy, start, end, **kwargs):
         start, end = 360 - end, 360 - start
         r = (360 + end - start) % 360
