@@ -16,6 +16,7 @@
 import re
 import math
 from itertools import islice, izip, tee
+from blockdiag.utils import ellipse, urlutil, XY
 from blockdiag.utils.myitertools import istep, stepslice
 from blockdiag.utils.PILTextFolder import PILTextFolder as TextFolder
 try:
@@ -28,9 +29,6 @@ except ImportError:
     import ImageDraw
     import ImageFont
     import ImageFilter
-from blockdiag.utils.XY import XY
-from blockdiag.utils import ellipse
-from blockdiag.utils import urlutil
 
 
 def point_pairs(xylist):
@@ -112,6 +110,12 @@ class ImageDrawEx(object):
         self.scale_ratio = kwargs.get('scale_ratio', 1)
         self.mode = kwargs.get('mode')
         self.draw = ImageDraw.ImageDraw(self.image, self.mode)
+        self.fontpath = None
+        self.fontsize = None
+
+    def set_default_font(self, fontpath, fontsize):
+        self.fontpath = fontpath
+        self.fontsize = fontsize
 
     def resizeCanvas(self, size):
         image = self.image.resize(size, Image.ANTIALIAS)
@@ -128,9 +132,10 @@ class ImageDrawEx(object):
         style = kwargs.get('style')
         if 'style' in kwargs:
             del kwargs['style']
+        if 'thick' in kwargs:
+            del kwargs['thick']
 
         if style:
-
             while start > end:
                 end += 360
 
@@ -171,6 +176,10 @@ class ImageDrawEx(object):
     def line(self, xy, **kwargs):
         if 'jump' in kwargs:
             del kwargs['jump']
+        if 'thick' in kwargs:
+            if kwargs['thick'] is not None:
+                kwargs['width'] = kwargs['thick']
+            del kwargs['thick']
 
         style = kwargs.get('style')
         if kwargs.get('fill') == 'none':
@@ -235,11 +244,10 @@ class ImageDrawEx(object):
 
     def text(self, xy, string, **kwargs):
         fill = kwargs.get('fill')
-        font = kwargs.get('font')
-        fontsize = kwargs.get('fontsize', 11)
 
-        if font:
-            ttfont = ImageFont.truetype(font, fontsize)
+        if self.fontpath:
+            fontsize = kwargs.get('fontsize') or self.fontsize
+            ttfont = ImageFont.truetype(self.fontpath, fontsize)
         else:
             ttfont = None
 
@@ -273,14 +281,21 @@ class ImageDrawEx(object):
             self.draw = ImageDraw.ImageDraw(self.image, self.mode)
 
     def textarea(self, box, string, **kwargs):
-        lines = TextFolder(box, string, scale=self.scale_ratio, **kwargs)
+        if 'fontsize' in kwargs:
+            fontsize = kwargs.get('fontsize') or self.fontsize
+            del kwargs['fontsize']
+        else:
+            fontsize = self.fontsize
+
+        lines = TextFolder(box, string, scale=self.scale_ratio,
+                           font=self.fontpath, fontsize=fontsize, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
-            self.rectangle(lines.outlineBox(), fill='white', outline=outline)
+            self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
-        for string, xy in lines.each_line():
-            self.text(xy, string, **kwargs)
+        for string, xy in lines.lines:
+            self.text(xy, string, fontsize=fontsize, **kwargs)
 
     def loadImage(self, filename, box):
         box_width = box[2] - box[0]
