@@ -16,8 +16,7 @@
 import re
 import sys
 import base64
-from blockdiag.utils.XY import XY
-from blockdiag.utils import urlutil
+from blockdiag.utils import urlutil, XY
 from simplesvg import *
 import xml.sax.saxutils
 
@@ -33,6 +32,10 @@ class SVGImageDrawElement(object):
     def __init__(self, svg):
         self.svg = svg
 
+    def set_default_font(self, fontpath, fontsize):
+        self.fontpath = fontpath
+        self.fontsize = fontsize
+
     def rgb(self, color):
         if isinstance(color, tuple):
             color = 'rgb(%d,%d,%d)' % color
@@ -73,7 +76,7 @@ class SVGImageDrawElement(object):
         self.svg.addElement(p)
 
     def rectangle(self, box, **kwargs):
-        thick = kwargs.get('width', 1)
+        thick = kwargs.get('width')
         fill = kwargs.get('fill', 'none')
         outline = kwargs.get('outline')
         style = kwargs.get('style')
@@ -92,32 +95,40 @@ class SVGImageDrawElement(object):
 
     def text(self, xy, string, **kwargs):
         fill = kwargs.get('fill')
-        fontname = kwargs.get('font')
-        fontsize = kwargs.get('fontsize')
+        fontsize = kwargs.get('fontsize') or self.fontsize
 
-        t = text(xy[0], xy[1], string, font_size=fontsize, fill=self.rgb(fill))
+        t = text(xy[0], xy[1], string,
+                 font_size=fontsize, fill=self.rgb(fill))
         self.svg.addElement(t)
 
     def textarea(self, box, string, **kwargs):
-        lines = TextFolder(box, string, adjustBaseline=True, **kwargs)
+        if 'fontsize' in kwargs:
+            fontsize = kwargs.get('fontsize') or self.fontsize
+            del kwargs['fontsize']
+        else:
+            fontsize = self.fontsize
+
+        lines = TextFolder(box, string, adjustBaseline=True,
+                           font=self.fontpath, fontsize=fontsize, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
-            self.rectangle(lines.outlineBox(), fill='white', outline=outline)
+            self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
-        for string, xy in lines.each_line():
-            self.text(xy, string, **kwargs)
+        for string, xy in lines.lines:
+            self.text(xy, string, fontsize=fontsize, **kwargs)
 
     def line(self, xy, **kwargs):
         fill = kwargs.get('fill')
         style = kwargs.get('style')
+        thick = kwargs.get('thick')
 
         pd = pathdata(xy[0].x, xy[0].y)
         for pt in xy[1:]:
             pd.line(pt.x, pt.y)
 
         p = path(pd, fill="none", stroke=self.rgb(fill),
-                 stroke_dasharray=self.style(style))
+                 stroke_width=thick, stroke_dasharray=self.style(style))
         self.svg.addElement(p)
 
     def arc(self, xy, start, end, **kwargs):
