@@ -14,9 +14,7 @@
 #  limitations under the License.
 
 import pkg_resources
-from blockdiag.utils import Box
-from blockdiag.utils.XY import XY
-from blockdiag.utils import images
+from blockdiag.utils import images, Box, XY
 
 renderers = {}
 searchpath = []
@@ -87,7 +85,7 @@ class NodeShape(object):
             node.background = ""
             for i in range(2, 0, -1):
                 r = self.metrics.cellsize / 2 * i
-                metrics = self.metrics.shiftedMetrics(r, 0, 0, r)
+                metrics = self.metrics.shift(r, r)
 
                 self.__class__(node, metrics).render(drawer, format,
                                                     stacked=True, **kwargs)
@@ -109,17 +107,14 @@ class NodeShape(object):
         pass
 
     def render_label(self, drawer, **kwargs):
-        font = kwargs.get('font')
-
         if not kwargs.get('shadow'):
             drawer.textarea(self.textbox, self.node.label,
                             fill=self.node.textcolor, halign=self.textalign,
-                            font=font, fontsize=self.metrics.fontsize,
-                            line_spacing=self.metrics.line_spacing)
+                            line_spacing=self.metrics.line_spacing,
+                            fontsize=self.node.fontsize)
 
     def render_number_badge(self, drawer, **kwargs):
         if self.node.numbered != None and kwargs.get('shadow') != True:
-            font = kwargs.get('font')
             outline = kwargs.get('outline')
             badgeFill = kwargs.get('badgeFill')
 
@@ -128,8 +123,7 @@ class NodeShape(object):
 
             box = (xy.x - r, xy.y - r, xy.x + r, xy.y + r)
             drawer.ellipse(box, outline=outline, fill=badgeFill)
-            drawer.textarea(box, self.node.numbered, fill=self.node.textcolor,
-                            font=font, fontsize=self.metrics.fontsize)
+            drawer.textarea(box, self.node.numbered, fill=self.node.textcolor)
 
     @property
     def top(self):
@@ -159,18 +153,10 @@ class NodeShape(object):
 
         if isinstance(value, XY):
             ret = XY(value.x + xdiff, value.y + ydiff)
-        elif isinstance(value, (list, tuple)):
-            if isinstance(value[0], (XY, list)):
-                ret = [self.shift_shadow(x) for x in value]
-            else:
-                ret = []
-                for i, x in enumerate(value):
-                    if i % 2 == 0:
-                        ret.append(x + xdiff)
-                    else:
-                        ret.append(x + ydiff)
         elif isinstance(value, Box):
             ret = Box(value.x1 + xdiff, value.y1 + ydiff,
                       value.x2 + xdiff, value.y2 + ydiff)
+        elif isinstance(value, (list, tuple)):
+            ret = [self.shift_shadow(x) for x in value]
 
         return ret
