@@ -15,7 +15,7 @@
 
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
-from blockdiag.utils.XY import XY
+from blockdiag.utils import XY
 
 
 class TextBox(NodeShape):
